# itpwriter

Tool to write ITPs using a Debian package source.

## Install

Available from pypi under the name 'itpwriter'.

```sh
pip install itpwriter
```

## Usage

Pass `--help` flag for usage info.

## Why?

I usually finish the d/control, d/changelog, and d/copyright files, and then copy their contents into an ITP. This program automates that.

## Copyright

Copyright &copy; 2023 Maytham Alsudany `<maytha8thedev@gmail.com>`

## License

MIT (aka Expat) unless otherwise indicated. See [LICENSE](./LICENSE).
